<?php

namespace EventPortal\Tests\Feature\Admin\Even§;

use EventPortal\Domain\Delegate\Models\DelegateFormData;
use EventPortal\Domain\Event\Form\Actions\DeleteForm;
use EventPortal\Domain\Event\Form\Models\Form;
use EventPortal\Domain\Event\Form\Models\FormStep;
use EventPortal\Domain\Event\Form\Models\FormStepSection;
use EventPortal\Domain\Event\Form\Models\Question;
use EventPortal\Domain\Event\Form\Models\QuestionOption;
use EventPortal\Domain\Event\Form\Models\QuestionValidation;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class DeleteFormTest extends TestCase
{
    use RefreshDatabase, SeedRolesAndPermissions;

    /** @test **/
    public function can_delete_a_form(): void
    {
        $event = factory(Event::class)->state('draft')->create();
        $form = factory(Form::class)->create(['event_id' => $event->id]);
        $step = factory(FormStep::class)->create(['form_id' => $form->id]);
        $section = factory(FormStepSection::class)->create(['form_step_id' => $step->id]);
        $question = factory(Question::class)->create(['form_step_section_id' => $section->id]);
        $option = factory(QuestionOption::class)->state('snapshot')->create(['question_id' => $question->id]);
        $validation = factory(QuestionValidation::class)->create(['question_id' => $question->id]);
        $delegateFormData = factory(DelegateFormData::class)->create(['question_id' => $question->id]);

        (new DeleteForm)->execute($form);

        $this->assertNull($form->fresh());
        $this->assertNull($step->fresh());
        $this->assertNull($section->fresh());
        $this->assertNull($question->fresh());
        $this->assertNull($option->fresh());
        $this->assertNull($validation->fresh());
        $this->assertNull($delegateFormData->fresh());
    }
}
