<?php

namespace EventPortal\Tests\Unit\Models;

use Carbon\Carbon;
use EventPortal\Domain\Agenda\Models\Agenda;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class AgendaTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_create_for_an_event()
    {
        $event = factory(Event::class)->create();

        Agenda::createForEvent($event, Carbon::createFromFormat('d/m/Y', '27/05/2020'));

        $this->assertEventHasAgendaFor($event, '2020-05-27');
    }

    /** @test **/
    public function can_scope_for_event()
    {
        $eventA = factory(Event::class)->create();
        $agendaA = factory(Agenda::class)->create(['event_id' => $eventA->id]);

        $eventB = factory(Event::class)->create();
        $agendaB = factory(Agenda::class)->create(['event_id' => $eventB->id]);

        $actual = Agenda::forEvent($eventA)->get();

        $this->assertCount(1, $actual);
        $this->assertContainsModel($agendaA, $actual);
        $this->assertNotContainsModel($agendaB, $actual);
    }

    /** @test **/
    public function can_scope_for_date()
    {
        $agendaA = factory(Agenda::class)->create(['date' => '2020-07-31']);
        $agendaB = factory(Agenda::class)->create(['date' => '2020-08-01']);

        $actual = Agenda::forDate('2020-08-01')->get();

        $this->assertCount(1, $actual);
        $this->assertNotContainsModel($agendaA, $actual);
        $this->assertContainsModel($agendaB, $actual);
    }
}
