<?php

namespace EventPortal\Tests\Unit\Delegate\Handlers;

use EventPortal\Domain\Delegate\Handlers\CreateDelegate;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Form\Payload;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Pipeline\Pipeline;

class CreateDelegateTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_create_delegate()
    {
        $model = factory(User::class)->create();

        $payload = Payload::make()->withModel($model);

        app(Pipeline::class)
            ->send($payload)
            ->through([new CreateDelegate])
            ->thenReturn();

        $this->assertDatabaseHas('delegates', [
            'user_id' => $model->id,
        ]);
    }

    /** @test **/
    public function delegate_is_added_to_context()
    {
        $model = factory(User::class)->create();

        $payload = Payload::make()->withModel($model);

        app(Pipeline::class)
            ->send($payload)
            ->through([new CreateDelegate])
            ->thenReturn();

        $this->assertInstanceOf(Delegate::class, $payload->getContext('delegate'));
    }
}
