<?php

namespace EventPortal\Tests\Unit\Event\Form\Actions;

use EventPortal\Domain\Event\Form\Models\Form;
use EventPortal\Domain\Event\Form\Models\FormStep;
use EventPortal\Domain\Event\Form\Models\FormStepSection;
use EventPortal\Domain\Event\Form\Models\Question;
use EventPortal\Domain\Event\Form\Models\QuestionOption;
use EventPortal\Domain\Event\Form\Models\QuestionValidation;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class DeleteFormTest extends TestCase
{
    use RefreshDatabase, SeedRolesAndPermissions;

    /** @test **/
    public function can_delete_a_form(): void
    {
        $event = factory(Event::class)->state('draft')->create();
        $form = factory(Form::class)->create(['event_id' => $event->id]);
        $step = factory(FormStep::class)->create(['form_id' => $form->id]);
        $section = factory(FormStepSection::class)->create(['form_step_id' => $step->id]);
        $question = factory(Question::class)->create(['form_step_section_id' => $section->id]);
        $option = factory(QuestionOption::class)->state('snapshot')->create(['question_id' => $question->id]);
        $validation = factory(QuestionValidation::class)->create(['question_id' => $question->id]);

        $this
            ->actingAsSuperAdmin()
            ->delete(route('admin.form.delete', [$event, $form]));

        $this->assertNull($form->fresh());
        $this->assertNull($step->fresh());
        $this->assertNull($section->fresh());
        $this->assertNull($question->fresh());
        $this->assertNull($option->fresh());
        $this->assertNull($validation->fresh());
    }

    /** @test **/
    public function cannot_delete_a_form_when_event_is_published(): void
    {
        $event = factory(Event::class)->state('published')->create();
        $form = factory(Form::class)->create(['event_id' => $event->id]);
        $step = factory(FormStep::class)->create(['form_id' => $form->id]);
        $section = factory(FormStepSection::class)->create(['form_step_id' => $step->id]);
        $question = factory(Question::class)->create(['form_step_section_id' => $section->id]);
        $option = factory(QuestionOption::class)->state('snapshot')->create(['question_id' => $question->id]);
        $validation = factory(QuestionValidation::class)->create(['question_id' => $question->id]);

        $this
            ->actingAsSuperAdmin()
            ->delete(route('admin.form.delete', [$event, $form]));

        $this->assertNotNull($form->fresh());
        $this->assertNotNull($step->fresh());
        $this->assertNotNull($section->fresh());
        $this->assertNotNull($question->fresh());
        $this->assertNotNull($option->fresh());
        $this->assertNotNull($validation->fresh());
    }
}
